options nocenter validvarname=any;

*---Read in space-delimited ascii file;

data new_data;


infile 'ya2020_sppc_raw_items.dat' lrecl=88 missover DSD DLM=' ' print;
input
  C0000100
  C0000200
  Y4570400
  Y4570500
  Y4570600
  Y4570700
  Y4570800
  Y4570900
  Y4571000
  Y4571100
  Y4571200
  Y4571300
  Y4571400
  Y4571500
  Y4571600
  Y4571700
  Y4571800
  Y4571900
  Y4572000
  Y4572100
  Y4572200
  Y4572300
  Y4572400
  Y4572500
  Y4572600
  Y4572700
;
array nvarlist _numeric_;


*---Recode missing values to SAS custom system missing. See SAS
      documentation for use of MISSING option in procedures, e.g. PROC FREQ;

do over nvarlist;
  if nvarlist = -1 then nvarlist = .R;  /* Refused */
  if nvarlist = -2 then nvarlist = .D;  /* Dont know */
  if nvarlist = -3 then nvarlist = .I;  /* Invalid missing */
  if nvarlist = -7 then nvarlist = .M;  /* Missing */
end;

  label C0000100 = "ID CODE OF CHILD";
  label C0000200 = "ID CODE OF MOTHER OF CHILD";
  label Y4570400 = "SPPC: R MORE LIKE GOOD AT/WORRY ABOUT SCHOOLWK 2020";
  label Y4570500 = "SPPC: HOW TRUE IS GOOD AT/WORRY ABOUT SCHOOLWK 2020";
  label Y4570600 = "SPPC: R MORE LIKE PLEASED/UNHAPPY WITH SELF 2020";
  label Y4570700 = "SPPC: HOW TRUE IS PLEASED/UNHAPPY WITH SELF 2020";
  label Y4570800 = "SPPC: R MORE LIKE FEEL/WONDER IF JUST AS SMART 2020";
  label Y4570900 = "SPPC: HOW TRUE IS FEEL/WONDER IF JUST AS SMART 2020";
  label Y4571000 = "SPPC: R MORE LIKE LIKE/DONT LIKE MY LIFE 2020";
  label Y4571100 = "SPPC: HOW TRUE IS LIKE/DONT LIKE MY LIFE 2020";
  label Y4571200 = "SPPC: R MORE LIKE DO SCHOOLWORK QUICKLY/SLOWLY 2020";
  label Y4571300 = "SPPC: HOW TRUE IS DO SCHOOLWORK QUICKLY/SLOWLY 2020";
  label Y4571400 = "SPPC: R MORE LIKE HAPPY/NOT HAPPY WITH SELF 2020";
  label Y4571500 = "SPPC: HOW TRUE IS HAPPY/NOT HAPPY WITH SELF 2020";
  label Y4571600 = "SPPC: R MORE LIKE REMEMBER/FORGET THINGS EASILY 2020";
  label Y4571700 = "SPPC: HOW TRUE IS REMEMBER/FORGET THINGS EASILY 2020";
  label Y4571800 = "SPPC: R MORE LIKE LIKE PERSON I AM/WISH ELSE 2020";
  label Y4571900 = "SPPC: HOW TRUE IS LIKE PERSON I AM/WISH ELSE 2020";
  label Y4572000 = "SPPC: R MORE LIKE DO/DONT DO WELL AT CLASSWORK 2020";
  label Y4572100 = "SPPC: HOW TRUE IS DO/DONT DO WELL AT CLASSWORK 2020";
  label Y4572200 = "SPPC: R MORE LIKE HAPPY WAY I AM/WISH DIFFERENT 2020";
  label Y4572300 = "SPPC: HOW TRUE IS HAPPY WAY I AM/WISH DIFFERENT 2020";
  label Y4572400 = "SPPC: R MORE LIKE CAN /HAVE TROUBLE FIG OUT ANS 2020";
  label Y4572500 = "SPPC: HOW TRUE IS CAN /HAVE TROUBLE FIG OUT ANS 2020";
  label Y4572600 = "SPPC: R MORE LIKE WAY I DO THNGS IS/IS NOT FINE 2020";
  label Y4572700 = "SPPC: HOW TRUE IS WAY I DO THNGS IS/IS NOT FINE 2020";

/*---------------------------------------------------------------------*
 *  Crosswalk for Reference number & Question name                     *
 *---------------------------------------------------------------------*
 * Uncomment and edit this RENAME statement to rename variables
 * for ease of use.  You may need to use  name literal strings
 * e.g.  'variable-name'n   to create valid SAS variable names, or 
 * alter variables similarly named across years.
 * This command does not guarantee uniqueness

 * See SAS documentation for use of name literals and use of the
 * VALIDVARNAME=ANY option.     
 *---------------------------------------------------------------------*/
  /* *start* */

* RENAME
  C0000100 = 'CPUBID_XRND'n
  C0000200 = 'MPUBID_XRND'n
  Y4570400 = 'Q16-SPPC-1A_2020'n
  Y4570500 = 'Q16-SPPC-1B_2020'n
  Y4570600 = 'Q16-SPPC-2A_2020'n
  Y4570700 = 'Q16-SPPC-2B_2020'n
  Y4570800 = 'Q16-SPPC-3A_2020'n
  Y4570900 = 'Q16-SPPC-3B_2020'n
  Y4571000 = 'Q16-SPPC-4A_2020'n
  Y4571100 = 'Q16-SPPC-4B_2020'n
  Y4571200 = 'Q16-SPPC-5A_2020'n
  Y4571300 = 'Q16-SPPC-5B_2020'n
  Y4571400 = 'Q16-SPPC-6A_2020'n
  Y4571500 = 'Q16-SPPC-6B_2020'n
  Y4571600 = 'Q16-SPPC-7A_2020'n
  Y4571700 = 'Q16-SPPC-7B_2020'n
  Y4571800 = 'Q16-SPPC-8A_2020'n
  Y4571900 = 'Q16-SPPC-8B_2020'n
  Y4572000 = 'Q16-SPPC-9A_2020'n
  Y4572100 = 'Q16-SPPC-9B_2020'n
  Y4572200 = 'Q16-SPPC-10A_2020'n
  Y4572300 = 'Q16-SPPC-10B_2020'n
  Y4572400 = 'Q16-SPPC-11A_2020'n
  Y4572500 = 'Q16-SPPC-11B_2020'n
  Y4572600 = 'Q16-SPPC-12A_2020'n
  Y4572700 = 'Q16-SPPC-12B_2020'n
;
  /* *finish* */

run;

proc means data=new_data n mean min max;
run;


/*---------------------------------------------------------------------*
 *  FORMATTED TABULATIONS                                              *
 *---------------------------------------------------------------------*
 * You can uncomment and edit the PROC FORMAT and PROC FREQ statements 
 * provided below to obtain formatted tabulations. The tabulations 
 * should reflect codebook values.
 * 
 * Please edit the formats below reflect any renaming of the variables
 * you may have done in the first data step. 
 *---------------------------------------------------------------------*/

/*
proc format; 
value vx0f
  1-9999999='1 TO 9999999: See Min & Max values below for range as of this release'
;
value vx1f
  1-12686='1 TO 12686: NLSY79 Public ID'
;
value vx2f
  1='THE FIRST ONES WHO FEEL THEY ARE VERY GOOD AT THEIR SCHOOL WORK'
  2='THE SECOND ONES WHO WORRY ABOUT WHETHER THEY CAN DO THE SCHOOL WORK ASSIGNED TO THEM'
;
value vx3f
  1='REALLY TRUE FOR ME'
  2='SORT OF TRUE FOR ME'
;
value vx4f
  1='THE FIRST ONES WHO ARE OFTEN UNHAPPY WITH THEMSELVES'
  2='THE SECOND ONES WHO ARE PRETTY PLEASED WITH THEMSELVES'
;
value vx5f
  1='REALLY TRUE FOR ME'
  2='SORT OF TRUE FOR ME'
;
value vx6f
  1='THE FIRST ONES WHO FEEL LIKE THEY ARE JUST AS SMART AS OTHER KIDS THEIR AGES'
  2='THE SECOND ONES WHO AREN''T SO SURE AND WONDER IF THEY ARE AS SMART'
;
value vx7f
  1='REALLY TRUE FOR ME'
  2='SORT OF TRUE FOR ME'
;
value vx8f
  1='THE FIRST ONES WHO DON''T LIKE THE WAY THEY ARE LEADING THEIR LIFE'
  2='THE SECOND ONES WHO DO LIKE THE WAY THEY ARE LEADING THEIR LIFE'
;
value vx9f
  1='REALLY TRUE FOR ME'
  2='SORT OF TRUE FOR ME'
;
value vx10f
  1='THE FIRST ONES WHO ARE PRETTY SLOW IN FINISHING THEIR SCHOOL WORK'
  2='THE SECOND ONES WHO CAN DO THEIR SCHOOL WORK QUICKLY'
;
value vx11f
  1='REALLY TRUE FOR ME'
  2='SORT OF TRUE FOR ME'
;
value vx12f
  1='THE FIRST ONES WHO ARE HAPPY WITH THEMSELVES AS A PERSON'
  2='THE SECOND ONES WHO ARE OFTEN NOT HAPPY WITH THEMSELVES AS A PERSON'
;
value vx13f
  1='REALLY TRUE FOR ME'
  2='SORT OF TRUE FOR ME'
;
value vx14f
  1='THE FIRST ONES WHO OFTEN FORGET WHAT THEY LEARN'
  2='THE SECOND ONES WHO CAN REMEMBER THINGS EASILY'
;
value vx15f
  1='REALLY TRUE FOR ME'
  2='SORT OF TRUE FOR ME'
;
value vx16f
  1='THE FIRST ONES WHO LIKE THE KIND OF PERSON THEY ARE'
  2='THE SECOND ONES WHO OFTEN WISH THEY WERE SOMEONE ELSE'
;
value vx17f
  1='REALLY TRUE FOR ME'
  2='SORT OF TRUE FOR ME'
;
value vx18f
  1='THE FIRST ONES WHO DO VERY WELL AT THEIR CLASSWORK'
  2='THE SECOND ONES WHO DON''T DO VERY WELL AT THEIR CLASSWORK'
;
value vx19f
  1='REALLY TRUE FOR ME'
  2='SORT OF TRUE FOR ME'
;
value vx20f
  1='THE FIRST ONES WHO ARE VERY HAPPY BEING THE WAY THEY ARE'
  2='THE SECOND ONES WHO WISH THEY WERE DIFFERENT'
;
value vx21f
  1='REALLY TRUE FOR ME'
  2='SORT OF TRUE FOR ME'
;
value vx22f
  1='THE FIRST ONES WHO HAVE TROUBLE FIGURING OUT THE ANSWERS IN SCHOOL'
  2='THE SECOND ONES WHO ALMOST ALWAYS CAN FIGURE OUT THE ANSWERS.'
;
value vx23f
  1='REALLY TRUE FOR ME'
  2='SORT OF TRUE FOR ME'
;
value vx24f
  1='THE FIRST ONES WHO ARE NOT VERY HAPPY WITH THE WAY THEY DO A LOT OF THINGS'
  2='THE SECOND ONES WHO THINK THE WAY THEY DO THINGS IS FINE'
;
value vx25f
  1='REALLY TRUE FOR ME'
  2='SORT OF TRUE FOR ME'
;
*/

/* 
 *--- Tabulations using reference number variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
  format C0000100 vx0f.;
  format C0000200 vx1f.;
  format Y4570400 vx2f.;
  format Y4570500 vx3f.;
  format Y4570600 vx4f.;
  format Y4570700 vx5f.;
  format Y4570800 vx6f.;
  format Y4570900 vx7f.;
  format Y4571000 vx8f.;
  format Y4571100 vx9f.;
  format Y4571200 vx10f.;
  format Y4571300 vx11f.;
  format Y4571400 vx12f.;
  format Y4571500 vx13f.;
  format Y4571600 vx14f.;
  format Y4571700 vx15f.;
  format Y4571800 vx16f.;
  format Y4571900 vx17f.;
  format Y4572000 vx18f.;
  format Y4572100 vx19f.;
  format Y4572200 vx20f.;
  format Y4572300 vx21f.;
  format Y4572400 vx22f.;
  format Y4572500 vx23f.;
  format Y4572600 vx24f.;
  format Y4572700 vx25f.;
run;
*/

/*
*--- Tabulations using default named variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
  format 'CPUBID_XRND'n vx0f.;
  format 'MPUBID_XRND'n vx1f.;
  format 'Q16-SPPC-1A_2020'n vx2f.;
  format 'Q16-SPPC-1B_2020'n vx3f.;
  format 'Q16-SPPC-2A_2020'n vx4f.;
  format 'Q16-SPPC-2B_2020'n vx5f.;
  format 'Q16-SPPC-3A_2020'n vx6f.;
  format 'Q16-SPPC-3B_2020'n vx7f.;
  format 'Q16-SPPC-4A_2020'n vx8f.;
  format 'Q16-SPPC-4B_2020'n vx9f.;
  format 'Q16-SPPC-5A_2020'n vx10f.;
  format 'Q16-SPPC-5B_2020'n vx11f.;
  format 'Q16-SPPC-6A_2020'n vx12f.;
  format 'Q16-SPPC-6B_2020'n vx13f.;
  format 'Q16-SPPC-7A_2020'n vx14f.;
  format 'Q16-SPPC-7B_2020'n vx15f.;
  format 'Q16-SPPC-8A_2020'n vx16f.;
  format 'Q16-SPPC-8B_2020'n vx17f.;
  format 'Q16-SPPC-9A_2020'n vx18f.;
  format 'Q16-SPPC-9B_2020'n vx19f.;
  format 'Q16-SPPC-10A_2020'n vx20f.;
  format 'Q16-SPPC-10B_2020'n vx21f.;
  format 'Q16-SPPC-11A_2020'n vx22f.;
  format 'Q16-SPPC-11B_2020'n vx23f.;
  format 'Q16-SPPC-12A_2020'n vx24f.;
  format 'Q16-SPPC-12B_2020'n vx25f.;
run;
*/